# ------------------------------------------------------ #
module SDM

	module Select_By_Attribute

		def self.main
			mod = Sketchup.active_model
			ent = mod.active_entities
			sel = mod.selection
			self.webdialog()
		end
		
		def self.webdialog()
			@dlg=UI::WebDialog.new("Select By Attribute", false,"WDID",300,200,10,10,true)
			
			html = <<-HTML
			<!DOCTYPE html>
			<html lang="en-US">
				<head>
					<meta charset="utf-8" />
					<meta content="IE=edge" http-equiv="X-UA-Compatible" />
					<script>
						var toFunc = typeof(Function),
						bAddEventListener = (typeof(window.addEventListener) === toFunc);
						
						function clearList(id) {
							var x = document.getElementById(id);
							while (x.length>0) {x.remove(0)};
						};
						
						function addToList(id,options) {
							var x = document.getElementById(id);
							for (i=0;i<options.length;i++) {
								var option = document.createElement('option');
								option.text = options[i];
								x.add(option);
							};
							x.selectIndex=0;
						};
						
						function tellSU(element) {
							id=element.id
							value=element.value
							window.location='skp:ValueChanged@'+id +'='+ value;
						};

						function winLoad() {
							window.location='skp:InitializeForm@';
						};
						
						if (bAddEventListener) {
							if ('DOMContentLoaded' in document)
								document.addEventListener('DOMContentLoaded', winLoad, false);
							else
								window.addEventListener('load', winLoad, false);
						} else {
							window.attachEvent('onload', winLoad);
						};
					</script>
				</head>
				<body>
						<table><tr><td align='right' width=30>
							Dictionary:</td><td><select id='dic' onChange='tellSU(this)'></select></td></tr>
							<tr><td align='right'>Key:</td><td><select id='key' onChange='tellSU(this)'></select></td></tr>
							<tr><td align='right'>Value:</td><td><select id='val' onChange='tellSU(this)'></select></td></tr>
							<tr><td><button id='btn' value='select' onclick='tellSU(this)'>Select</button></td></tr>
						</table>
				</body>
			</html>
			HTML

			@dlg.set_html(html)
			
			RUBY_PLATFORM =~ /(darwin)/ ? @dlg.show_modal() : @dlg.show();
			
			@dlg.add_action_callback("InitializeForm") { |d,p|
				self.get_attributes
				puts "Initializing Form"
				@dlg.execute_script("clearList('dic'); addToList('dic',['#{@dict_names.join("','")}']);")
				@dlg.execute_script("clearList('key'); addToList('key',['#{@dict_keys.join("','")}']);")
				@dlg.execute_script("clearList('val'); addToList('val',['#{@key_values.join("','")}']);")
			};

			@dlg.add_action_callback("ValueChanged") { |d,p|
				var, val = p.strip.split("=")
				puts p
				case var
					when 'dic' then @name=val
					when 'key' then @key=val
					when 'val' then @value=val
					when 'btn' then select_by_attribute
				end
			};
			
		end

		def self.get_attributes
			model=Sketchup.active_model
			ents=model.active_entities	
			@dict_names=[]; @dict_keys=[]; @key_values=[]
			for e in ents 		
				next unless e.attribute_dictionaries
				for ad in e.attribute_dictionaries	
					@dict_names << ad.name
					@dict_keys << e.attribute_dictionary(ad.name).keys
					@key_values << e.attribute_dictionary(ad.name).values
				end				
			end				
			@dict_names.flatten!; @dict_names.uniq!; @name = @dict_names[0]
			@dict_keys.flatten!; @dict_keys.uniq!; @key = @dict_keys[0]
			@key_values.flatten!; @key_values.uniq!; @value = @key_values[0]
		end				

		def self.select_by_attribute
			mod = Sketchup.active_model
			ent = mod.entities
			sel = mod.selection
			sel.clear
			for e in ent
				next unless e.attribute_dictionaries
				names = e.attribute_dictionaries.map{|ad| ad.name}
				if ( names.include?(@name) &&
						 e.attribute_dictionary(@name).keys.include?(@key) &&
						 e.attribute_dictionary(@name).values.include?(@value) )
					sel.add e
				end
			end
		end

	end
end


